<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\DB;

use Inertia\Inertia;
use Inertia\Response;

use App\Models\Favourite;

class FavouritesController extends Controller
{
    /**
     * Show the All Products view.
     */
    public function showFavourites(Request $request): Response
    {
        $userid = $request->user()->id;
        $perPage = $request->input('per_page', 10);
        $favourites = Favourite::where('user_id', $userid)
        ->paginate($perPage);

        $favourites = DB::table('favourites')
            ->join('products', 'favourites.product_id', '=', 'products.id')
            ->where('user_id', $userid)
            ->select('favourites.*', 'favourites.id as fav_id', 'products.*')
            ->get();

        return Inertia::render('Favourites', [
            'per_page' => $perPage,
            'favourites' => $favourites,
            'userid' => $userid,
        ]);
    }

    public function addFavourite(Request $request): RedirectResponse
    {
        $request->validate([
            'user_id' => 'required|integer',
            'product_id' => 'required|integer',
        ]);

        $favourite = Favourite::create([
            'user_id' => $request->user_id,
            'product_id' => $request->product_id,
        ]);

        return Redirect::back();
    }

    public function deleteFavourite($id)
    {
        $userid = auth()->id();

        $favourite = Favourite::find($id);

        if (!$favourite) {
            return Inertia::render('Favourites', [
                'status' => 'Favourite not found',
            ]);
        }

        $favourite->delete();
        $favourites = DB::table('favourites')
            ->join('products', 'favourites.product_id', '=', 'products.id')
            ->where('user_id', $userid)
            ->get();
        $favourites = Favourite::all();

        return Redirect::back()->with('status', 'Product deleted successfully')->with('favourites', $favourites);
    }
}
