<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;

use Illuminate\Support\Facades\Redirect;
use App\Http\Controllers\Admin\SettingsController;

use Inertia\Inertia;
use Inertia\Response;

use App\Models\Product;
use App\Models\CarMake;
use App\Models\CarModel;
use App\Models\CarBodyStyle;
use App\Models\Favourite;
use App\Models\Cart;
use App\Models\Settings;

class ProductController extends Controller
{
    protected $settings;

    public function __construct(SettingsController $settings)
    {
        $this->settings = $settings;
    }
    /**
     * Show the All Products view.
     */
    public function show(Request $request): Response
    {
        $perPage = $request->input('per_page', 30);

        $query = Product::query();

        if(isset($_REQUEST['year']) && !empty($_REQUEST['year'])) {
            $query->where('year', 'like', '%'.$_REQUEST['year'].'%');
        }

        if(isset($_REQUEST['make']) && !empty($_REQUEST['make'])) {
            $query->where('make', 'like', '%'.$_REQUEST['make'].'%');
        }

        if(isset($_REQUEST['model']) && !empty($_REQUEST['model'])) {
            $query->where('model', 'like', '%'.$_REQUEST['model'].'%');
        }

        if(isset($_REQUEST['bodystyle']) && !empty($_REQUEST['bodystyle'])) {
            $query->where('bodystyle', 'like', '%'.$_REQUEST['bodystyle'].'%');
        }

        $products = $query->orderBy('item_number', 'desc')->take(50)->get();

        $userid = $request->user()->id;
        $query = Favourite::query();
        $favourites = $query->where('user_id', $userid)->get();
        $cart = Cart::where('user_id', $userid)->get();

        return Inertia::render('Products', [
            'products' => $products,
            'per_page' => $perPage,
            'favourites' => $favourites,
            'cart' => $cart,
            'settings' => $this->settings->getValues(),
        ]);
    }

    public function singleProduct($id): Response
    {
        $query = Product::query();
        if(isset($id) && !empty($id)) {
            $query->where('item_number', $id);
        }

        $product = $query->orderBy('item_number', 'desc')->get();

        $make = CarMake::where('id',$product[0]->make)->value('name');
        $model = CarModel::where('id',$product[0]->model)->value('name');
        $bodystyle = CarBodyStyle::where('id',$product[0]->bodystyle)->value('name');


        if (!$product) {
            return Inertia::render('SingleProduct', [
                'status' => 'Product not found',
            ]);
        }

        $relatedProducts = Product::where('make', $product[0]->make)
        ->orWhere('model', $product[0]->model)
        ->whereNotIn('id', [$product[0]->id])
        ->inRandomOrder()
        ->limit(2)
        ->get();

        return Inertia::render('SingleProduct', [
            'product' => $product,
            'relatedProducts' => $relatedProducts,
        ]);
    }
}
