<?php
use App\Http\Controllers\UserAccountController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\FavouritesController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\CheckoutController;
use App\Http\Controllers\Admin\AdminProfileController;
use Illuminate\Foundation\Application;
use Illuminate\Support\Facades\Route;
use Inertia\Inertia;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return Inertia::render('Welcome', [
        'canLogin' => Route::has('login'),
        'canRegister' => Route::has('register'),
        'laravelVersion' => Application::VERSION,
        'phpVersion' => PHP_VERSION,
    ]);
});

Route::get('/dashboard', function () {
    return Inertia::render('Dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

    Route::get('/products', [ProductController::class, 'show'])->name('products.all');
    Route::get('/product/{id}', [ProductController::class, 'singleProduct'])->name('product.single');

    Route::get('/favourites', [FavouritesController::class, 'showFavourites'])->name('products.favourites');
    Route::post('/add-to-favourite', [FavouritesController::class, 'addFavourite'])->name('product.favourite');
    Route::post('/delete-favourite/{id}', [FavouritesController::class, 'deleteFavourite'])->name('favourite.delete');

    Route::post('/add-to-cart', [CartController::class, 'addToCart'])->name('cart.add');
    Route::post('/update-cart', [CartController::class, 'updateCart'])->name('cart.update');
    Route::post('/clear-cart', [CartController::class, 'clearCart'])->name('cart.clear');
    Route::get('/cart', [CartController::class, 'showCart'])->name('cart.items');
    Route::post('/delete-cart/{id}', [CartController::class, 'deleteCartProduct'])->name('cart.item.delete');

    Route::get('/checkout', [CheckoutController::class, 'checkout'])->name('checkout');
    Route::post('/checkout', [CheckoutController::class, 'saveOrder'])->name('save.order');

    Route::post('/save-address', [CheckoutController::class, 'saveAddress'])->name('save.address');

    Route::get('/order/{id}', [CheckoutController::class, 'orderDetail'])->name('order.detail');

    Route::get('/myaccount', [UserAccountController::class, 'myaccount'])->name('user.myaccount');
});

require __DIR__.'/auth.php';
require __DIR__.'/AdminAuth.php';

Route::middleware('auth:admin')->group(function () {

    Route::get('/admin/dashboard', function () {
        return Inertia::render('Admin/Dashboard');
    })->name('admin.dashboard');

    Route::get('/admin/profile', [AdminProfileController::class, 'edit'])->name('admin.profile.edit');
    Route::patch('/admin/profile', [ProfileController::class, 'update'])->name('admin.profile.update');
    // Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});
